@@ -1,5 +1,5 @@
 #__main__.py
-from . import sample
+from sample import sample
 import json
 
 def main():
